Learn R Programming

CEDARS (version 1.90)

mrrel_upload: Upload UMLS Relationships

Description

Prepares and uploads UMLS MRREL.RRF file. This file is not included in the CEDARS package and can be obtained on the NIH web site at https://www.nlm.nih.gov/research/umls/index.html. It is very large and not currently used by CEDARS.

Usage

mrrel_upload(path, uri_fun, user, password, host, port, database)

Arguments

path

Path to file MRREL.RRF.

uri_fun

Uniform resource identifier (URI) string generating function for MongoDB credentials.

user

MongoDB user name.

password

MongoDB user password.

host

MongoDB host server.

port

MongoDB port.

database

MongoDB database name.

Value

Progress report of UMLS processing and upload.

Examples

Run this code
# NOT RUN {
mrrel_upload(path = 'dictionaries/MRREL.RRF', uri_fun = mongo_uri_standard, user = 'John',
password = 'db_password_1234', host = 'server1234', port = NA, database = 'TEST_PROJECT')
# }

Run the code above in your browser using DataLab